@@ -101,7 +101,7 @@ typedef struct {
 #define Decoder_read_PROTO (DecoderObj *self, int amf3)
 
 #define Decoder_readByte_NUM 6
-#define Decoder_readByte_RETURN char
+#define Decoder_readByte_RETURN char*
 #define Decoder_readByte_PROTO (DecoderObj *self)
 
 #ifdef CONTEXT_MODULE
